import { AbstractSession } from "@zowe/imperative";
import { IGetWorkflowsOptions } from "./doc/IGetWorkflowsOptions";
/**
 * Get list of workflows from registry.
 * @export
 * @class ListWorkflows
 */
export declare class ListWorkflows {
    /**
     * This operation returns list of workflows.
     * Parameters are optional,request can include one or more parameters to filter the results.
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {IGetWorkflowsOptions} options - Options to filter the request
     * @returns {string} z/OSMF response object
     * @memberof ListWorkflows
     */
    static getWorkflows(session: AbstractSession, options?: IGetWorkflowsOptions): Promise<object>;
    /**
     * This operation Builds URI path from provided parameters.
     * @param {IGetWorkflowsOptions} params - The array with URI path with filters for listing filtered workflows.
     * @returns {string} URI path for the REST call.
     * @memberof ListWorkflows
     */
    static getResourceQuery(params: IGetWorkflowsOptions): string;
    /**
     * This operation is used to return a worflow-key by given workflow name.
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {string} workflowName - workflow name by which to list workflows
     * @param {string} zOSMFVersion - identifies the version of the provisioning service.
     * @returns {Promise<string> | null} - Promise with string containing wf key, or null if none was found
     * @throws {ImperativeError}
     * @memberof ListWorkflows
     */
    static getWfKey(session: AbstractSession, workflowName: string, zOSMFVersion?: string): Promise<string> | null;
}
