"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const utilities_1 = require("../../../../../utilities");
/**
 * Edit config
 */
class EditHandler {
    /**
     * Process the command and input.
     *
     * @param {IHandlerParameters} params Parameters supplied by yargs
     *
     * @throws {ImperativeError}
     */
    process(params) {
        return __awaiter(this, void 0, void 0, function* () {
            // Load the config and set the active layer according to user options
            const config = utilities_1.ImperativeConfig.instance.config;
            config.api.layers.activate(params.arguments.userConfig, params.arguments.globalConfig);
            const configLayer = config.api.layers.get();
            if (!configLayer.exists) {
                const initCmd = utilities_1.ImperativeConfig.instance.commandLine.replace("edit", "init");
                params.response.console.log(`File does not exist: ${configLayer.path}\n` +
                    `To create it, run "${utilities_1.ImperativeConfig.instance.rootCommandName} ${initCmd}".`);
            }
            else {
                yield utilities_1.ProcessUtils.openInEditor(utilities_1.ImperativeConfig.instance.config.api.layers.get().path);
            }
        });
    }
}
exports.default = EditHandler;
//# sourceMappingURL=edit.handler.js.map