"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash = require("lodash");
const config_1 = require("../../../../../config");
const utilities_1 = require("../../../../../utilities");
class ListHandler {
    /**
     * Process the command and input.
     *
     * @param {IHandlerParameters} params Parameters supplied by yargs
     *
     * @throws {ImperativeError}
     */
    process(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = utilities_1.ImperativeConfig.instance.config;
            const property = params.arguments.property;
            // Populate the print object
            let obj = {};
            if (config.exists) {
                if (params.arguments.locations) {
                    for (const layer of config.layers) {
                        if (layer.exists) {
                            obj[layer.path] = layer.properties;
                            if (obj[layer.path] != null) {
                                for (const secureProp of config.api.secure.secureFields(layer)) {
                                    if (lodash.has(obj[layer.path], secureProp)) {
                                        lodash.set(obj[layer.path], secureProp, config_1.ConfigConstants.SECURE_VALUE);
                                    }
                                }
                            }
                            if (property != null)
                                obj[layer.path] = layer.properties[property];
                        }
                    }
                }
                else {
                    obj = config.maskedProperties;
                    if (property != null)
                        obj = config.maskedProperties[property];
                }
            }
            // If requested, only include the root property
            if (params.arguments.root && lodash.isObject(obj)) {
                obj = Object.keys(obj);
            }
            // output to terminal
            params.response.data.setObj(obj);
            params.response.format.output({
                output: obj,
                format: (Array.isArray(obj)) ? "list" : "object"
            });
        });
    }
}
exports.default = ListHandler;
//# sourceMappingURL=list.handler.js.map