"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ConfigSchema_1 = require("../../../../../config/src/ConfigSchema");
const ImperativeExpect_1 = require("../../../../../expect/src/ImperativeExpect");
const ImperativeConfig_1 = require("../../../../../utilities/src/ImperativeConfig");
const TextUtils_1 = require("../../../../../utilities/src/TextUtils");
class UpdateSchemasHandler {
    /**
     * Process the command and input.
     *
     * @param {IHandlerParameters} params Parameters supplied by yargs
     *
     * @throws {ImperativeError}
     */
    process(params) {
        return __awaiter(this, void 0, void 0, function* () {
            ImperativeExpect_1.ImperativeExpect.toNotBeNullOrUndefined(ImperativeConfig_1.ImperativeConfig.instance.loadedConfig, "Failed to load profile schemas");
            const updatedPaths = ConfigSchema_1.ConfigSchema.updateSchema({ layer: "all", depth: params.arguments.depth });
            // output to terminal
            params.response.data.setObj(updatedPaths);
            params.response.console.log("Configuration files found: " + Object.keys(updatedPaths).length.toString());
            if (Object.keys(updatedPaths).length > 0) {
                const outputObj = {};
                for (const [schema, schemaInfo] of Object.entries(updatedPaths)) {
                    outputObj[TextUtils_1.TextUtils.chalk.yellow(schema)] = {
                        [`${schemaInfo.updated ? TextUtils_1.TextUtils.chalk.green("updated") : TextUtils_1.TextUtils.chalk.red("skipped")}`]: schemaInfo.schema
                    };
                }
                params.response.format.output({
                    output: outputObj,
                    format: "object"
                });
            }
        });
    }
}
exports.default = UpdateSchemasHandler;
//# sourceMappingURL=update-schemas.handler.js.map