"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.NextVerFeatures = void 0;
/**
 * This class contains logic to enable users to opt-in to features
 * that will become standard functionality in the next version of Zowe.
 * @export
 * @class NextVerFeatures
 */
class NextVerFeatures {
    /**
     * Identify if we should use the V3 error message format.
     * That choice is determined by the value of the ZOWE_V3_ERR_FORMAT environment variable.
     *
     * TODO:V3_ERR_FORMAT - Remove in V3
     *
     * @returns {boolean} True -> Use the V3 format.
     */
    static useV3ErrFormat() {
        // our default is false
        let v3ErrFmtBoolVal = false;
        const v3ErrFmtStringVal = process.env[`${NextVerFeatures.ENV_VAR_PREFIX}_V3_ERR_FORMAT`];
        if (v3ErrFmtStringVal !== undefined) {
            // user has set the V3 error format environment variable
            if (v3ErrFmtStringVal.toUpperCase() === "TRUE") {
                v3ErrFmtBoolVal = true;
            }
        }
        return v3ErrFmtBoolVal;
    }
}
exports.NextVerFeatures = NextVerFeatures;
NextVerFeatures.ENV_VAR_PREFIX = "ZOWE";
//# sourceMappingURL=NextVerFeatures.js.map